def _mem_usage(df):
    """ iterate through all the columns of a dataframe and modify the data type
        to reduce memory usage.
        source: https://gist.github.com/enamoria/fa9baa906f23d1636c002e7186516a7b
    """
    mem = df.memory_usage().sum() / 1024 ** 2

    return '{:.2f} MB'.format(mem)



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='pd_helper',
    version='0.0.10',
    author='Justin Chae',
    author_email='justin@chaemail.com',
    description = 'A helpful script to optimize a Pandas DataFrame.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/justinhchae/pd-helper",
    project_urls={
        "Download URL": "https://github.com/justinhchae/pd-helper/archive/refs/tags/v0.0.9-beta.tar.gz",
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="pd_helper"),
    python_requires=">=3.6",
)
